<?php
/**
 * TPC! Memory Usage Formatting API
 * 
 * @package TPC_Memory_Usage
 * @subpackage Formatting
 */

/**
 * Converts bytes to megabytes.
 * 
 * @param int The number of bytes.
 * @return int The number of megabytes.
 */
function tpc_bytes_to_mb($value) {
	if ( $value == 0 )
		return 0;
	
	$value = round( $value / 1024 / 1024, 2 );
	
	return $value;
}

/**
 * Make percent using two given values, and attach suffix, if necessary.
 * 
 * @param int $value1 Memory usage, peak or otherwise. (for our purposes)
 * @param int $value2 Memory limit. If not set, defaults to WP_MEMORY_LIMIT.
 * @param string $suffix Defaults to false. Example $suffix is '%'.
 * @return string|int Formatted percentage string.
 */
function tpc_make_percent($value1, $value2 = false, $suffix = false) {
	global $tpcmem;
	
	if ( !$value2 )
		$value2 = WP_MEMORY_LIMIT;
	
	if ( $value2 <= 0 )
		return 0;
	
	$value = round( $value1 / $value2 * 100, 0 );
	
	if ( false === $suffix )
		return $value;
	
	return $value . $suffix;
}

?>