<?php
/**
 * TPC! Memory Usage Class File
 * 
 * @package TPC_Memory_Usage
 */

class tpcmem {
	/**
	 * TPC! Memory Usage plugin version
	 * 
	 * @access private
	 * @var string
	 */
	var $version = '0.3';
	
	/**
	 * Last recorded memory usage
	 * 
	 * @var int
	 */
	var $memory_usage;
	
	/**
	 * Last recorded peak memory usage
	 * 
	 * @var int
	 */
	var $memory_peak_usage;
	
	/**
	 * PHP memory limit
	 * 
	 * @var string
	 */
	var $php_memory_limit;
	
	/**
	 * Highest recorded memory usage
	 * 
	 * @access public
	 * @var array
	 */
	var $current_peak_usage;
	
	/**
	 * Whether or not to record the peak usage
	 * 
	 * @access public
	 * @var string
	 */
	var $record_peak_usage;
	
	/**
	 * Whether or not to update peak memory usage in database
	 * 
	 * @access public
	 * @var bool
	 */
	var $update_peak_usage;
	
	/**
	 * Number of times get_peak_usage() was called.
	 * 
	 * @access public
	 * @var int
	 */
	var $count_get_peak_usage;
	
	/**
	 * Number of times get_usage() was called.
	 * 
	 * @access public
	 * @var int
	 */
	var $count_get_usage;
	
	/**
	 * PHP5-Style Constructor
	 * 
	 * Initializes main variables when initiated.
	 */
	function __construct() {
		// Initialize variables when class is initiated...
		$this->count_get_usage = 0;
		$this->count_get_peak_usage = 0;
		$this->update_peak_usage = false;
		
		$this->get_usage();
		$this->get_peak_usage();
		$this->php_memory_limit = ( @ini_get('memory_limit') ) ? ini_get('memory_limit') : 'N/A';
	}
	
	/**
	 * Get current memory usage for script.
	 * 
	 * @uses memory_get_usage() To get current memory usage.
	 * 
	 * @return int Current memory usage.
	 */
	function get_usage() {
		if ( function_exists('memory_get_usage') ) {
			$memory_usage = memory_get_usage();
			$this->memory_usage = $memory_usage;
		} else {
			$this->memory_usage = 0;
		}
		
		tpc_memory_usage_log($this->memory_usage);
		
		$this->count_get_usage++;
		
		return $this->memory_usage;
	}
	
	/**
	 * Get peak memory usage for script.
	 * 
	 * @param $real_usage Set this to true to get the real size of memory allocated from the system.
	 * @return int Peak memory usage.
	 */
	function get_peak_usage($real_usage = false) {
		if ( function_exists('memory_get_peak_usage') ) {
			$memory_peak_usage = memory_get_peak_usage($real_usage);
			$this->memory_peak_usage = $memory_peak_usage;
		} else {
			$this->memory_peak_usage = 0;
		}
		
		tpc_memory_usage_log($this->memory_peak_usage);
		
		$this->count_get_peak_usage++;
		
		return $this->memory_peak_usage;
	}
	
	/**
	 * Get the current memory limit for PHP.
	 * 
	 * @return string|int The memory limit. (May be in either format: 32M or 32, 64M or 64, etc.)
	 */
	function get_limit() {
		return $this->php_memory_limit;
	}
	
	/**
	 * Get the lesser of the two memory limits (WP_MEMORY_LIMIT and 'memory_limit' as stated in php.ini).
	 * 
	 * @param string|false $suffix Defaults to nothing. Adds suffix to returned string.
	 * @return int|string The lesser of the two memory limit settings.
	 */
	function get_lesser_limit($suffix = false) {
		$php_limit = (int) str_replace('M', '', $this->php_memory_limit);
		$wp_limit = (int) str_replace('M', '', WP_MEMORY_LIMIT);
		
		$limit = ($php_limit < $wp_limit) ? $php_limit : $wp_limit;
		
		if ( !$suffix )
			return $limit;
		return $limit . $suffix;
	}
	
	/**
	 * PHP4 compatibility function
	 * 
	 * Executes $tpcmem->__construct().
	 */
	function tpcmem() {
		$this->__construct();
	}
}

add_action('plugins_loaded', 'tpc_memory_usage_init');

?>